pecos.qeclib.steane.gates\_sq.sqrt\_paulis
==========================================

.. automodule:: pecos.qeclib.steane.gates_sq.sqrt_paulis











   .. rubric:: Classes

   .. autosummary::

      SX
      SXdg
      SY
      SYdg
      SZ
      SZdg
